@@ -27,7 +27,7 @@
 #' see example.
 #' @examples
 #' library(sf)
-#' library(maps)
+#' if (require(maps, quietly = TRUE)) {
 #'
 #' usa = st_as_sf(map('usa', plot = FALSE, fill = TRUE))
 #' laea = st_crs("+proj=laea +lat_0=30 +lon_0=-95") # Lambert equal area
@@ -59,10 +59,15 @@
 #'			srt = g$angle_end[i] - 90, pos = 3, cex = .7)
 #' }))
 #' plot(usa, graticule = st_crs(4326), axes = TRUE, lon = seq(-60,-130,by=-10))
+#' }
 st_graticule = function(x = c(-180,-90,180,90), crs = st_crs(x),
 	datum = st_crs(4326), ..., lon = NULL, lat = NULL, ndiscr = 100,
 	margin = 0.001)
 {
+	s2 = sf_use_s2()
+	on.exit(suppressMessages(sf_use_s2(s2)))
+	suppressMessages(sf_use_s2(FALSE))
+
 	if (missing(x)) {
 		crs = datum
 		if (is.null(lon))
@@ -220,7 +225,7 @@ trim_bb = function(bb = c(-180, -90, 180, 90), margin, wrap=c(-180,180)) {
 degreeLabelsNS = function(x) {
 	pos = sign(x) + 2
 	dir = c("*S", "", "*N")
-	paste0('"', abs(x), '"', "*degree", dir[pos])
+	paste0('"', format(abs(x), digits = 10), '"', "*degree", dir[pos])
 }
 
 degreeLabelsEW = function(x) {
@@ -231,5 +236,5 @@ degreeLabelsEW = function(x) {
 	if (any(x == 180))
 		pos[x == 180] = 2
 	dir = c("*W", "", "*E")
-	paste0('"', abs(x), '"', "*degree", dir[pos])
+	paste0('"', format(abs(x), digits = 10), '"', "*degree", dir[pos])
 }
