@@ -1,5 +1,3 @@
-context("sf: read tests")
-
 test_that("we can read a shapefile using st_read", {
   nc <- st_read(system.file("shape/nc.shp", package="sf"), "nc", crs = 4267, quiet = TRUE)
   expect_identical(class(nc), c("sf", "data.frame"))
@@ -144,7 +142,7 @@ test_that("guess_driver_can_write", {
 test_that("driver operations", {
   # These tests are driver specifics to GDAL version and OS.
   expect_error(guess_driver_can_write("x.e00"), "cannot write")
-  expect_error(guess_driver_can_write("x.gdb"), "cannot write")
+  # expect_error(guess_driver_can_write("x.gdb"), "cannot write") -> no longer the case when GDAL >= 3.6.0
 
   expect_equal(guess_driver_can_write("x.geojson"), c("geojson" = "GeoJSON"))
   expect_equal(guess_driver_can_write("x.csv"), c("csv" = "CSV"))
@@ -180,8 +178,8 @@ test_that("reading non-spatial table works", {
     expect_warning(st_read(system.file("gpkg/nospatial.gpkg", package = "sf")),
                    "no simple feature geometries present")
     expect_warning(
-        expect_is(st_read(system.file("gpkg/nospatial.gpkg", package = "sf")),
-                  "data.frame"),
+        expect_s3_class(st_read(system.file("gpkg/nospatial.gpkg", package = "sf")),
+                        "data.frame"),
         "no simple feature geometries"
     )
 #   expect_warning(
