@@ -1,5 +1,3 @@
-context("sf: write")
-
 if (require(sp, quietly = TRUE)) {
 data(meuse, package = "sp")
 meuse <- st_as_sf(meuse, coords = c("x", "y"), crs = 28992)
@@ -16,6 +14,7 @@ test_that("sf can write to all writable formats", {
 				"nc",  # requires appropriate datum -> but writes in 4326, see below
 				"map", # doesn't support points
 				"ods", # generates valgrind error
+				"gdb", # https://github.com/r-spatial/sf/issues/2027
 				"gpx") # needs specially named attributes
     for (ext in setdiff(names(extension_map[extension_map %in% drvs]), excluded_drivers)) {
         expect_silent(st_write(meuse, paste0(tf, ".", ext), quiet = TRUE))
@@ -32,14 +31,14 @@ test_that("sf can write to netcdf", {
 })
 
 test_that("sf can write units (#264)", {
-	skip_if_not_installed("sp")
-    tf <- tempfile(fileext = ".gpkg")
-    meuse[["length"]] <- meuse[["cadmium"]]
-    units(meuse$length) <- units::as_units("km")
-    st_write(meuse, tf, quiet = TRUE)
-    disc <- st_read(tf, quiet = TRUE)
-    expect_is(disc[["length"]], "numeric")
-    expect_equal(as.numeric(meuse[["length"]]), disc[["length"]])
+  skip_if_not_installed("sp")
+  tf <- tempfile(fileext = ".gpkg")
+  meuse[["length"]] <- meuse[["cadmium"]]
+  units(meuse$length) <- units::as_units("km")
+  st_write(meuse, tf, quiet = TRUE)
+  disc <- st_read(tf, quiet = TRUE)
+  expect_type(disc[["length"]], "double")
+  expect_equal(as.numeric(meuse[["length"]]), disc[["length"]])
 })
 
 test_that("delete and update work (#304)", {
@@ -87,8 +86,8 @@ test_that("delete and update work (#304)", {
   expect_silent(x <- st_read(gpkg, quiet = TRUE))
   x <- st_sf(a = 1:2, geom = st_sfc(st_linestring(matrix(1:4,2,2)),
 	st_multilinestring(list(matrix(1:4,2,2), matrix(10:13,2,2)))))
-  expect_silent(write_sf(x, shp, "x"))
-  expect_silent(write_sf(x, shp, delete_dsn = TRUE))
+  expect_message(write_sf(x, shp, "x"), "writing: substituting ENGCRS")
+  expect_message(write_sf(x, shp, delete_dsn = TRUE), "writing: substituting ENGCRS")
   expect_silent(x <- st_read(shp, quiet = TRUE))
   expect_silent(x <- read_sf(shp))
   expect_error(st_write(x, shp, driver = character(0), quiet = TRUE)) # err
